==> requesto-py-1.0.0.tar.gz: requesto-py-1.0.0/README.md <==
# requesto-py
Lightweight python wrapper library for psycopg2 and sqlite3 databases without tons of useless code. 


![GitHub top language](https://img.shields.io/github/languages/top/SolidUsr/requesto-py)
![GitHub](https://img.shields.io/github/license/SolidUsr/requesto-py)
![GitHub Repo stars](https://img.shields.io/github/stars/SolidUsr/requesto-py)
![GitHub issues](https://img.shields.io/github/issues/SolidUsr/requesto-py)


## Ways of Installation (Linux/Windows)

Before installation make sure to install all dependencies! No-dependencies branch [\*click\*](https://github.com/SOLIDusr/requesto-py/tree/no-dependencies) coming soon!

1. Clone repo 
```git clone https://github.com/SOLIDusr/requesto-py.git```

2. ```pip3 install requesto-py``` coming soon!

   
## Docs
You can check docs [\*here\*](./docs/lang.md).

[Realeses]: https://github.com/SolidUsr/requesto-py/releases

## Support
You can create new issue if you have questions, or you found a bug
[\*create\*](https://github.com/SolidUsr/requesto-py/issues/new/choose) or just message me here <reply.naromori@gmail.com> using requesto-py as an email topic.

## Dependencies 
This library currently in testing stage and can be broken somewhere (Tested on python 3.10 and pip 23.3.1). If you found out that this works in versions below stated or doesn't work by any chance or reason - message me
[Here!](https://github.com/SolidUsr/requesto-py#support)

## Commit tags
| Tag      | Describtion                                                     |
|----------|-----------------------------------------------------------------|
| sec      | Security issues                                                 |
| docs	   | Docs update.                                                    |
| upd  	   | Adding new features. (Updates)                                  |
| fix	   |   Fixing issues and bugs.                                         |
| perf	   | Perfomance or time issue fixes.                                 |
| refactor | Change of the code without adding any new features.             |
| revert   | /undo all the changes to the previous commits                   |
| style	   | Some changes of code to improve readability                     |
| test	   | Adding tests. (I promise i won't spam main branch with useless things)|

==> requesto-py-1.0.0.3.tar.gz: requesto-py-1.0.0.3/README.md <==
# requesto-py
Lightweight python wrapper library for psycopg2 and sqlite3 databases without tons of useless code. 


![GitHub top language](https://img.shields.io/github/languages/top/SolidUsr/requesto-py)
![GitHub](https://img.shields.io/github/license/SolidUsr/requesto-py)
![GitHub Repo stars](https://img.shields.io/github/stars/SolidUsr/requesto-py)
![GitHub issues](https://img.shields.io/github/issues/SolidUsr/requesto-py)


## Ways of Installation (Linux/Windows)

Before installation make sure to install all dependencies! No-dependencies branch [\*click\*](https://github.com/SOLIDusr/requesto-py/tree/no-dependencies) coming soon!

1. Clone repo 
```git clone https://github.com/SOLIDusr/requesto-py.git```

2. ```pip install requesto-py```

   
## Docs
You can check docs [\*here\*](./temp/lang.md).

[Realeses]: https://github.com/SolidUsr/requesto-py/releases

## Support
You can create new issue if you have questions, or you found a bug
[\*create\*](https://github.com/SolidUsr/requesto-py/issues/new/choose) or just message me here <reply.naromori@gmail.com> using requesto-py as an email topic.

## Dependencies 
This library currently in testing stage and can be broken somewhere (Tested on python 3.10 and pip 23.3.1). If you found out that this works in versions below stated or doesn't work by any chance or reason - message me
[Here!](https://github.com/SolidUsr/requesto-py#support)

## Commit tags
| Tag      | Describtion                                                     |
|----------|-----------------------------------------------------------------|
| sec      | Security issues                                                 |
| docs	   | Docs update.                                                    |
| upd  	   | Adding new features. (Updates)                                  |
| fix	   |   Fixing issues and bugs.                                         |
| perf	   | Perfomance or time issue fixes.                                 |
| refactor | Change of the code without adding any new features.             |
| revert   | /undo all the changes to the previous commits                   |
| style	   | Some changes of code to improve readability                     |
| test	   | Adding tests. (I promise i won't spam main branch with useless things)|
